//
//  BDCloudFastQuery.h
//  BDLogServiceSDK
//
//  Created by v_linaying on 2020/8/4.
//  Copyright © 2020 v_linaying. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@interface BDCloudFastQuery : NSObject

- (instancetype)initWithSigner:(id<BDCloudSigner>)signer;

/**
Create FastQuery
@param fastQueryName 快速查询名称
@param query 快速查询语句
@param description 信息描述
@param logStoreName 日志集的名称
@param logStreamName 日志流名称
@param completionHandler completion call back
*/
- (void)createFastQueryWithFastQueryName:(NSString *)fastQueryName query:(NSString *)query description:(NSString *)description logStoreName:(NSString *)logStoreName logStreamName:(NSString *)logStreamName completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;


/**
Get DescribeFastQuery
@param fastQueryName 快速查询名称
@param completionHandler completion call back
 其中返回数据字典结构如下
 参数名称    类型    描述
 creationDateTime    DateTime    日志集创建的日期时间
 lastModifiedTime    DateTime    最后修改的日期时间
 fastQueryName    String    快速查询名称
 description    String    描述信息
 query    String    快速查找语句
 logStoreName    String    日志集名称
 logStreamName    String    日志流名称
*/
- (void)getDescribeFastQueryWithFastQueryName:(NSString *)fastQueryName completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

/**
Create FastQuery
@param fastQueryName 快速查询名称
@param description 信息描述
@param query 快速查询语句
@param logStoreName 日志集名称
@param logStreamName 日志流名称
@param completionHandler completion call back
*/
- (void)updateFastQueryWithFastQueryName:(NSString *)fastQueryName description:(NSString *)description query:(NSString *)query logStoreName:(NSString *)logStoreName logStreamName:(NSString *)logStreamName completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

/**
Delete FastQuery
@param fastQueryName 快速查询名称
@param completionHandler completion call back
*/
- (void)deleteFastQueryWithFastQueryName:(NSString *)fastQueryName completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

/**
Get ListFastQuery
@param namePattern 指定筛选名称的关键字
@param order 排序规则，desc为降序，asc为升序，默认为 desc
@param orderBy 排序字段，默认为创建时间
@param pageNo 起始页码，默认为 1
@param pageSize 每页显示数据大小，默认为 10
@param completionHandler completion call back
 其中返回数据字典结构如下
 参数名称    类型    描述
 order    String    排序规则，desc为降序，asc为升序
 orderBy    String    排序字段
 pageNo    Int    起始页码
 pageSize    Int    每页显示数据大小
 totalCount    Int    总数目
 result    List<FastQuery>    返回的结果集
*/
- (void)getListFastQueryWithNamePattern:(NSString *)namePattern order:(NSString *)order orderBy:(NSString *)orderBy pageNo:(int)pageNo pageSize:(int)pageSize completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

@end

NS_ASSUME_NONNULL_END
