//
//  BDCloudLogRecord.h
//  BDLogServiceSDK
//
//  Created by v_linaying on 2020/8/4.
//  Copyright © 2020 v_linaying. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@interface BDCloudLogRecord : NSObject

- (instancetype)initWithSigner:(id<BDCloudSigner>)signer;

/**
PushLogRecord
@param logStoreName 日志集名称
@param logStreamName 日志流名称，长度不能超过 128 字符，包含的字符仅限于：a-z, A-Z, 0-9, '_', '-', '.'
@param type 数据类型，JSON/TEXT，默认为 TEXT
@param logRecords 日志记录<LogRecord>
@param completionHandler completion call back
*/
- (void)pushLogRecordWithLogLogStoreName:(NSString *)logStoreName logStreamName:(NSString *)logStreamName type:(NSString *)type logRecords:(NSArray *)logRecords completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;


/**
PullLogRecord
@param logStoreName 日志集名称
@param logStreamName 日志流名称
@param startDateTime 起始日期时间，包括起始时间
@param endDateTime 结束日期时间，不包括结束时间
@param limit 指定返回的最大条目数，默认值1000
@param marker 指定查看的位置标记
@param completionHandler completion call back
 其中返回数据字典结构如下
 result    List<LogRecord>    一组日志记录
 marker    String    返回的位置标记
 isTruncated    Boolean    true: 表示后面还有数据，false: 表示已经是最后一页
 nextMarker    String    下次查看的起始位置，可在翻页的时候作为 marker 在请求里携带LogRecord 字段说明
 timestamp    Int    日志时间戳，精确到毫秒
 message    String    日志内容，如果用户上传的日志是TEXT类型，那么就是日志原文，否则为日志中的k-v 对组成的json 字符串
*/
- (void)pullLogRecordWithLogLogStoreName:(NSString *)logStoreName logStreamName:(NSString *)logStreamName startDateTime:(NSString *)startDateTime endDateTime:(NSString *)endDateTime limit:(int)limit marker:(NSString *)marker completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

/**
Query LogStore
@param logStoreName 日志集名称
@param logStreamName 日志流名称
@param sql 输入的SQL语句
@param startDateTime 起始日期时间，包括起始时间
@param endDateTime 结束日期时间，不包括结束时间
@param limit 指定返回的最大条目数，默认值1000
@param marker 指定查看的位置标记
@param completionHandler completion call back
 其中，resultSet 代表此次查询获取的结果集，其结构定义如下：
 参数名称    类型    是否必须    描述
 columns    List<string>    是    包含的字段名称列表
 rows    List<List<obj>>    是    每一行对应columns中列名的值
 isTruncated    Boolean    是    结果集是否被截断
 truncatedReason    String    否    返回结果集被截断的原因
 
 datasetScanInfo 代表扫描原始数据集的统计信息，其结构定义如下：
 参数名称    类型    是否必须    描述
 isTruncated    Boolean    是    数据扫描是否被截断
 truncatedReason    String    否    数据扫描被截断的原因
 nextMarker    String    否    标记数据扫描被截断的位置
 marker    String    否    透传请求中的 marker，用来标识本次查询的起始位置
 statistics    Object    是    数据集扫描的一些统计信息
 
 statistics 代表本次查询所扫描的原始数据集的统计信息：

 参数名称    类型    是否必须    描述
 executionTimeInMs    Int    是    本次查询花费的时间，单位毫秒
 scanCount    Int    是    本次查询所扫描的数据条数
 histogram    Object    是    本次查询扫描的日志按时间分布的直方图
 
 histogram 代表本次查询所扫描的原始数据集的直方图分布信息：

 参数名称    类型    是否必须    描述
 interval    Int    是    直方图统计单个区间大小
 startTime    DateTime    是    直方图统计的开始时间，是请求中的startDateTime，统计数据包括该时间
 endTime    DateTime    是    直方图统计的结束时间，是请求中的endDateTime，统计数据不包括该时间
 counts    List<Integer>    是    直方图统计区间的扫描条数
 注：startTime/endTime 遵循 ISO8601 格式标准，例如：2019-12-01T00:00:00Z
*/
- (void)queryLogRecordWithLogLogStoreName:(NSString *)logStoreName logStreamName:(NSString *)logStreamName sql:(NSString *)sql startDateTime:(NSString *)startDateTime endDateTime:(NSString *)endDateTime limit:(int)limit marker:(NSString *)marker completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

@end

NS_ASSUME_NONNULL_END
