//
//  BDCloudLogStore.h
//  BDLogServiceSDK
//
//  Created by v_linaying on 2020/8/4.
//  Copyright © 2020 v_linaying. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@interface BDCloudLogStore : NSObject

- (instancetype)initWithSigner:(id<BDCloudSigner>)signer;

/**
Create LogStore
@param logStoreName 日志集名称
@param retention 日志集的租期，单位：天数，最大值不超过30天
@param completionHandler completion call back
*/
- (void)createLogStoreWithLogStoreName:(NSString *)logStoreName retention:(int)retention completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

/**
Update LogStore
@param logStoreName 日志集名称
@param retention 日志集的租期，单位：天数，最大值不超过30天
@param completionHandler completion call back
*/
- (void)updateLogStoreWithLogStoreName:(NSString *)logStoreName retention:(int)retention completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

/**
Get LogStore Describe
@param logStoreName 日志集名称
@param completionHandler completion call back
 其中返回数据字典结构如下
 参数名称    类型    描述
 creationDateTime    DateTime    日志集创建的日期时间
 lastModifiedTime    DateTime    最后修改的日期时间
 logStoreName    String    日志集名称
 retention    Int    存储时长
*/
- (void)getDescribeLogStoreWithLogStoreName:(NSString *)logStoreName completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

/**
Delete LogStore
@param logStoreName 日志集名称
@param completionHandler completion call back
*/
- (void)deleteLogStoreWithLogStoreName:(NSString *)logStoreName completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

/**
get LogStore List
@param namePattern 指定筛选日志集的关键字
@param order 排序规则，desc为降序，asc为升序，默认为 desc
@param orderBy 排序字段，默认为创建时间
@param pageNo 起始页码，默认为 1
@param pageSize 每页显示数据大小，默认为 10
@param completionHandler completion call back
 其中返回数据字典结构如下
 order    String    排序规则，desc为降序，asc为升序
 orderBy    String    排序字段
 pageNo    Int    起始页码
 pageSize    Int    每页显示数据大小
 totalCount    Int    总数目
 result    List<LogStore>    LogStore 列表
*/
- (void)getListLogStoreWithNamePattern:(NSString *)namePattern order:(NSString *)order orderBy:(NSString *)orderBy pageNo:(int)pageNo pageSize:(int)pageSize completion:(void(^)(NSDictionary *resultDic, NSError *error))completionHandler;

@end

NS_ASSUME_NONNULL_END
